==> rss-0.9a2-20060106.zip: src/org/logical_paradox/rss/router/RNodeDSyncMngr.java <==
/*
 * $Id: RNodeDSyncMngr.java,v 1.2 2005/10/22 16:27:27 rampil Exp $
 * Copyright (c) 2005 LOGICAL-PARADOX.ORG
 */
package org.logical_paradox.rss.router;

import java.util.Vector;

import org.logical_paradox.common.net.IPAddressRangeSet;
import org.logical_paradox.rss.dsync.RSSSyncConfig;
import org.logical_paradox.rss.dsync.RSSSyncDaemon;
import org.logical_paradox.rss.dsync.RSSSyncInterface;
import org.logical_paradox.rss.dsync.SyncCommand;
import org.logical_paradox.rss.dsync.SyncQueueException;
import org.logical_paradox.rss.http.URLPool;

/**
 * oHm[h/RSSWebNavigatorɂxf[^񑗂̃[eBeBD
 * ̃NXgƁCbN̍ǗȂǂłD
 * @author satoshi akabane@logical-paradox.org
 * @version $Revision: 1.2 $
 */
public class RNodeDSyncMngr extends RSSSyncDaemon {
	/** TbNǗIuWFNg */
	private final SiteLockMgr lockMgr;
	/** URLv[ */
	private final URLPool pool;

	/**
	 * RXgN^D
	 * IPAhX͈̓Zbgw肳ĂꍇC͈͓̔ŒTbN𔭍sD
	 * IPAhX͈͐ݒ肪w肳ĂȂꍇCSĂIPAhXT̑ΏۂƂȂD
	 * @param daemonConfig RtBO[V
	 * @param dsi C^[tF[X
	 * @param expire TbN̗L
	 * @param p URLv[
	 * @param rs IPAhX͈̓Zbg(null:͈͐Ȃ)
	 * @throws Exception CX^X̐Ɏs
	 */
	public RNodeDSyncMngr(RSSSyncConfig daemonConfig, RSSSyncInterface dsi, long expire, URLPool p, IPAddressRangeSet rs) throws Exception {
		super(daemonConfig, dsi);

		if(rs != null) {
			lockMgr = new RestrictedSiteLockMgr(expire, rs);
		} else {
			lockMgr = new SiteLockMgr(expire);
		}
		pool = p;
	}

	/**
	 * bNǉD
	 * bNǉ邱ƂłꍇtrueCsꍇfalseԂD<br>
	 * IPAhX͈͐ݒɂ鐧ꍇC͈͓̔łȂ΃bN擾ɎsD<br>
	 * ܂CۗLĂ郍bNꍇۂD<br>
	 * IPAhX͈͐ݒ͈͓̔̃TCgC邢IPAhX͈̓Zbgݒ肳ĂȂꍇC<br>
	 * bN̎擾ɐ(͂)D
	 * @param l bN悤ƂĂTbNIuWFNg
	 * @return true:bN擾 / false:bN擾s
	 * @throws SynQueueException 炩̗RŏɎs
	 */
	public boolean lock(SiteLock l) throws SyncQueueException {
		boolean rc = lockMgr.lock(l);
		if(rc == true) {
			// bNǉł̂ŁC
			add(new SyncCommand(l, SyncCommand.COMMAND_LOCK, null, null));
		}
		return rc;
	}

	/**
	 * w肳ꂽbN擾
	 * w肳Tm[hIDŎ擾łȂꍇnull
	 */
	public SiteLock findLock(String dn, String rid) {
		return lockMgr.findLock(dn, rid);
	}

	/**
	 * TCgbÑS~
	 * S~̃XgzŕԂ
	 */
	public SiteLock[] gc() {
		SiteLock[] removedObjLocal = lockMgr.gc();			// [JGC
		Vector removedObjRemote = new Vector();				// L[ɍڂꂽAbN

		// ؂ō폜ꂽTbNUNLOCKƂđ̃m[hւ]
		try {
			for(int i = 0; i < removedObjLocal.length; i++) {
				unlock(removedObjLocal[i]);
				removedObjRemote.addElement(removedObjLocal[i]);
			}
		} catch(SyncQueueException se) {
			// L[ςɂȂĂ邭̂ŁCI
			// c͎ɉ񂵂Ă݂
		}

		return (SiteLock[])removedObjRemote.toArray(new SiteLock[1]);
	}

	/**
	 * wID̒Tm[hۗLĂ郍bN̐Ԃ
	 */
	public int numOfMyLocks(String robotId) {
		return lockMgr.numOfMyLocks(robotId);
	}

	/**
	 * URLv[Ԃ
	 */
	public URLPool getPool() {
		return pool;
	}

	/**
	 * bN
	 */
	public void unlock(SiteLock l) throws SyncQueueException {
		lockMgr.unlock(l);
		add(new SyncCommand(l, SyncCommand.COMMAND_UNLOCK, null, null));
	}

	/**
	 * URLǉ
	 */
	public void poolURL(String url) throws SyncQueueException {
		add(new SyncCommand(url, SyncCommand.COMMAND_FORWARD_URL, null, null));
	}

	/**
	 * URL폜
	 */
	public void dropURL(String url) throws SyncQueueException {
		add(new SyncCommand(url, SyncCommand.COMMAND_UNFORWARD_URL, null, null));
	}

	/**
	 * xf[̏I
	 *̃\bhĂяoƁCxf[̃obt@tbVȂSɏI
	 */
	public void done() {
		interrupt();
	}
}

// end of RNodeDSyncMngr.java

==> rss-1.0b1-20060227.zip: src/org/logical_paradox/rss/router/RNodeDSyncMngr.java <==
/*
 * $Id: RNodeDSyncMngr.java,v 1.3 2006/01/26 16:27:33 rampil Exp $
 * Copyright (c) 2005 LOGICAL-PARADOX.ORG
 */
package org.logical_paradox.rss.router;

import java.util.Vector;

import org.logical_paradox.common.net.IPAddressRangeSet;
import org.logical_paradox.rss.dsync.RSSSyncConfig;
import org.logical_paradox.rss.dsync.RSSSyncDaemon;
import org.logical_paradox.rss.dsync.RSSSyncInterface;
import org.logical_paradox.rss.dsync.SyncCommand;
import org.logical_paradox.rss.dsync.SyncQueueException;
import org.logical_paradox.rss.http.URLPool;

/**
 * oHm[h/RSSWebNavigatorɂxf[^񑗂̃[eBeBD
 * ̃NXgƁCbN̍ǗȂǂłD
 * @author satoshi akabane@logical-paradox.org
 * @version $Revision: 1.3 $
 */
public class RNodeDSyncMngr extends RSSSyncDaemon {
	/** TbNǗIuWFNg */
	private final SiteLockMgr lockMgr;
	/** URLv[ */
	private final URLPool pool;

	/**
	 * RXgN^D
	 * IPAhX͈̓Zbgw肳ĂꍇC͈͓̔ŒTbN𔭍sD
	 * IPAhX͈͐ݒ肪w肳ĂȂꍇCSĂIPAhXT̑ΏۂƂȂD
	 * @param daemonConfig RtBO[V
	 * @param dsi C^[tF[X
	 * @param expire TbN̗L
	 * @param p URLv[
	 * @param rs IPAhX͈̓Zbg(null:͈͐Ȃ)
	 * @throws Exception CX^X̐Ɏs
	 */
	public RNodeDSyncMngr(RSSSyncConfig daemonConfig, RSSSyncInterface dsi, long expire, URLPool p, IPAddressRangeSet rs) throws Exception {
		super(daemonConfig, dsi);

		if(rs != null) {
			lockMgr = new RestrictedSiteLockMgr(expire, rs);
		} else {
			lockMgr = new SiteLockMgr(expire);
		}
		pool = p;
	}

	/**
	 * bNǉD
	 * bNǉ邱ƂłꍇtrueCsꍇfalseԂD<br>
	 * IPAhX͈͐ݒɂ鐧ꍇC͈͓̔łȂ΃bN擾ɎsD<br>
	 * ܂CۗLĂ郍bNꍇۂD<br>
	 * IPAhX͈͐ݒ͈͓̔̃TCgC邢IPAhX͈̓Zbgݒ肳ĂȂꍇC<br>
	 * bN̎擾ɐ(͂)D
	 * @param l bN悤ƂĂTbNIuWFNg
	 * @return true:bN擾 / false:bN擾s
	 * @throws SynQueueException 炩̗RŏɎs
	 */
	public boolean lock(SiteLock l) throws SyncQueueException {
		boolean rc = lockMgr.lock(l);
		if(rc == true) {
			// bNǉł̂ŁC
			add(new SyncCommand(l, SyncCommand.COMMAND_LOCK, null, null));
		}
		return rc;
	}

	/**
	 * w肳ꂽbN擾
	 * w肳Tm[hIDŎ擾łȂꍇnull
	 */
	public SiteLock findLock(String dn, String rid) {
		return lockMgr.findLock(dn, rid);
	}

	/**
	 * TCgbÑS~
	 * S~̃XgzŕԂ
	 */
	public SiteLock[] gc() {
		SiteLock[] removedObjLocal = lockMgr.gc();						// [JGC
		Vector<SiteLock> removedObjRemote = new Vector<SiteLock>();		// L[ɍڂꂽAbN

		// ؂ō폜ꂽTbNUNLOCKƂđ̃m[hւ]
		try {
			for(int i = 0; i < removedObjLocal.length; i++) {
				unlock(removedObjLocal[i]);
				removedObjRemote.addElement(removedObjLocal[i]);
			}
		} catch(SyncQueueException se) {
			// L[ςɂȂĂ邭̂ŁCI
			// c͎ɉ񂵂Ă݂
		}

		return (SiteLock[])removedObjRemote.toArray(new SiteLock[1]);
	}

	/**
	 * wID̒Tm[hۗLĂ郍bN̐Ԃ
	 */
	public int numOfMyLocks(String robotId) {
		return lockMgr.numOfMyLocks(robotId);
	}

	/**
	 * URLv[Ԃ
	 */
	public URLPool getPool() {
		return pool;
	}

	/**
	 * bN
	 */
	public void unlock(SiteLock l) throws SyncQueueException {
		lockMgr.unlock(l);
		add(new SyncCommand(l, SyncCommand.COMMAND_UNLOCK, null, null));
	}

	/**
	 * URLǉ
	 */
	public void poolURL(String url) throws SyncQueueException {
		add(new SyncCommand(url, SyncCommand.COMMAND_FORWARD_URL, null, null));
	}

	/**
	 * URL폜
	 */
	public void dropURL(String url) throws SyncQueueException {
		add(new SyncCommand(url, SyncCommand.COMMAND_UNFORWARD_URL, null, null));
	}

	/**
	 * xf[̏I
	 *̃\bhĂяoƁCxf[̃obt@tbVȂSɏI
	 */
	public void done() {
		interrupt();
	}
}

// end of RNodeDSyncMngr.java
